;==============================================================================
; File: HC12.I
; Func: Assembly Language Register Definitions for HC812A4 & HC912B32
; Rem.: Source: MC68HC812A4, MC68HC912B32 Technical Summary (Motorola 1996)
; Copr: (C)1998 by Oliver Thamm
; Date: 24.05.1998
;==============================================================================

REGBASE	=	$0000			; Below: [A=HC812A4|B=HC912B32]

PORTA	=	REGBASE+$0000	; [A|B] Port A Register
PORTB	=	REGBASE+$0001	; [A|B] Port B Register
DDRA	=	REGBASE+$0002	; [A|B] Port A Data Direction Register
DDRB	=	REGBASE+$0003	; [A|B] Port B Data Direction Register
PORTC	=	REGBASE+$0004	; [A|-] Port C Register
PORTD	=	REGBASE+$0005	; [A|-] Port D Register
DDRC	=	REGBASE+$0006	; [A|-] Port C Data Direction Register
DDRD	=	REGBASE+$0007	; [A|-] Port D Data Direction Register
PORTE	=	REGBASE+$0008	; [A|B] Port E Register
DDRE	=	REGBASE+$0009	; [A|B] Port E Data Direction Register
PEAR	=	REGBASE+$000a	; [A|B] Port E Assignment Register
MODE	=	REGBASE+$000b	; [A|B] Mode Register
PUCR	=	REGBASE+$000c	; [A|B] Pull Up Control Register
RDRIV	=	REGBASE+$000d	; [A|B] Reduced Drive of I/O Lines

INITRM	=	REGBASE+$0010	; [A|B] Initialization of Internal RAM Position Register 
INITRG	=	REGBASE+$0011	; [A|B] Initialization of Internal Register Position Register
INITEE	=	REGBASE+$0012	; [A|B] Initialization of Internal EEPROM Position Register
MISC	=	REGBASE+$0013	; [A|B] Miscellaneous Mapping Register
RTICTL	=	REGBASE+$0014	; [A|B] Real-Time Interrupt Control Register
RTIFLG	=	REGBASE+$0015	; [A|B] Real-Time Interrupt Flag Register
COPCTL	=	REGBASE+$0016	; [A|B] COP Control Register
COPRST	=	REGBASE+$0017	; [A|B] Arm/Reset COP Timer Register
ITST0	=	REGBASE+$0018	; [A|B] Reserved
ITST1	=	REGBASE+$0019	; [A|B] Reserved
ITST2	=	REGBASE+$001a	; [A|B] Reserved
ITST3	=	REGBASE+$001b	; [A|B] Reserved

INTCR	=	REGBASE+$001e	; [A|B] Interrupt Control Register
HPRIO	=	REGBASE+$001f	; [A|B] Highest Priority I Interrupt
KWIED	=	REGBASE+$0020	; [A|-] Key Wakeup Port D Interrupt Enable Register
BRKCT0	=	REGBASE+$0020	; [-|B] Breakpoint Control Register 0
KWIFD	=	REGBASE+$0021	; [A|-] Key Wakeup Port D Flag Register
BRKCT1	=	REGBASE+$0021	; [-|B] Breakpoint Control Register 1
BRKAH	=	REGBASE+$0022	; [-|B] Breakpoint Address Register (High Byte)
BRKAL	=	REGBASE+$0023	; [-|B] Breakpoint Address Register (Low Byte)
PORTH	=	REGBASE+$0024	; [A|-] Port H Register
BRKDH	=	REGBASE+$0024	; [-|B] Breakpoint Data Register (High Byte)
DDRH	=	REGBASE+$0025	; [A|-] Port H Data Direction Register
BRKDL	=	REGBASE+$0025	; [-|B] Breakpoint Data Register (Low Byte)
KWIEH	=	REGBASE+$0026	; [A|-] Key Wakeup Port H Interrupt Enable Register
KWIFH	=	REGBASE+$0027	; [A|-] Key Wakeup Port H Flag Register
PORTJ	=	REGBASE+$0028	; [A|-] Port J Register
DDRJ	=	REGBASE+$0029	; [A|-] Port J Data Direction Register
KWIEJ	=	REGBASE+$002a	; [A|-] Key Wakeup Port J Interrupt Enable Register
KWIFJ	=	REGBASE+$002b	; [A|-] Key Wakeup Port J Flag Register
KPOLJ	=	REGBASE+$002c	; [A|-] Key Wakeup Port J Polarity Register
PUPSJ	=	REGBASE+$002d	; [A|-] Key Wakeup Port J Pull-Up/Pulldown Select Register
PULEJ	=	REGBASE+$002e	; [A|-] Key Wakeup Port J Pull-Up/Pulldown Enable Register

PORTF	=	REGBASE+$0030	; [A|-] Port F Register
PORTG	=	REGBASE+$0031	; [A|-] Port G Register
DDRF	=	REGBASE+$0032	; [A|-] Port F Data Direction Register
DDRG	=	REGBASE+$0033	; [A|-] Port G Data Direction Register
DPAGE	=	REGBASE+$0034	; [A|-] Data Page Register
PPAGE	=	REGBASE+$0035	; [A|-] Program Page Register
EPAGE	=	REGBASE+$0036	; [A|-] Extra Page Register
WINDEF	=	REGBASE+$0037	; [A|-] Window Definition Register
MXAR	=	REGBASE+$0038	; [A|-] Memory Expansion Assignment Register

CSCTL0	=	REGBASE+$003c	; [A|-] Chip Select Control Register 0
CSCTL1	=	REGBASE+$003d	; [A|-] Chip Select Control Register 1
CSSTR0	=	REGBASE+$003e	; [A|-] Chip Select Stretch Register 0
CSSTR1	=	REGBASE+$003f	; [A|-] Chip Select Stretch Register 1
LDV		=	REGBASE+$0040	; [A|-] Loop Divider Registers (Word)
PWCLK	=	REGBASE+$0040	; [-|B] PWM Clocks and Concatenate
PWPOL	=	REGBASE+$0041	; [-|B] PWM Clock Select and Polarity
RDV		=	REGBASE+$0042	; [A|-] Reference Divider Register (Word)
PWEN	=	REGBASE+$0042	; [-|B] PWM Enable
PWPRES	=	REGBASE+$0043	; [-|B] PWM Prescale Counter
PWSCAL0	=	REGBASE+$0044	; [-|B] PWM Scale Register 0
PWSCNT0	=	REGBASE+$0045	; [-|B] PWM Scale Counter 0 Value
PWSCAL1	=	REGBASE+$0046	; [-|B] PWM Scale Register 1
CLKCTL	=	REGBASE+$0047	; [A|-] Clock Control Register
PWSCNT1	=	REGBASE+$0047	; [-|B] PWM Scale Counter 1 Value
PWCNT0	=	REGBASE+$0048	; [-|B] PWM Channel 0 Counter
PWCNT1	=	REGBASE+$0049	; [-|B] PWM Channel 1 Counter
PWCNT2	=	REGBASE+$004a	; [-|B] PWM Channel 2 Counter
PWCNT3	=	REGBASE+$004b	; [-|B] PWM Channel 3 Counter
PWPER0	=	REGBASE+$004c	; [-|B] PWM Channel 0 Period Register
PWPER1	=	REGBASE+$004d	; [-|B] PWM Channel 1 Period Register
PWPER2	=	REGBASE+$004e	; [-|B] PWM Channel 2 Period Register
PWPER3	=	REGBASE+$004f	; [-|B] PWM Channel 3 Period Register
PWDTY0	=	REGBASE+$0050	; [-|B] PWM Channel 0 Duty Register
PWDTY1	=	REGBASE+$0051	; [-|B] PWM Channel 1 Duty Register
PWDTY2	=	REGBASE+$0052	; [-|B] PWM Channel 2 Duty Register
PWDTY3	=	REGBASE+$0053	; [-|B] PWM Channel 3 Duty Register
PWCTL	=	REGBASE+$0054	; [-|B] PWM Control Register
PWTST	=	REGBASE+$0055	; [-|B] PWM Special Mode Register
PORTP	=	REGBASE+$0056	; [-|B] Port P Data Register
DDRP	=	REGBASE+$0057	; [-|B] Port P Data Direction Register

ATDCTL0	=	REGBASE+$0060	; [A|B] Reserved
ATDCTL1	=	REGBASE+$0061	; [A|B] Reserved
ATDCTL2	=	REGBASE+$0062	; [A|B] ATD Control Register 2
ATDCTL3	=	REGBASE+$0063	; [A|B] ATD Control Register 3
ATDCTL4	=	REGBASE+$0064	; [A|B] ATD Control Register 4
ATDCTL5	=	REGBASE+$0065	; [A|B] ATD Control Register 5
ATDSTAT	=	REGBASE+$0066	; [A|B] ATD Status Register (Word)
ATDTEST	=	REGBASE+$0068	; [A|B] ATD Test Register (Word)

PORTAD	=	REGBASE+$006f	; [A|B] Port AD Data Input Register

ADR0H	=	REGBASE+$0070	; [A|B] A/D Converter Result Register 0

ADR1H	=	REGBASE+$0072	; [A|B] A/D Converter Result Register 1

ADR2H	=	REGBASE+$0074	; [A|B] A/D Converter Result Register 2

ADR3H	=	REGBASE+$0076	; [A|B] A/D Converter Result Register 3

ADR4H	=	REGBASE+$0078	; [A|B] A/D Converter Result Register 4

ADR5H	=	REGBASE+$007a	; [A|B] A/D Converter Result Register 5

ADR6H	=	REGBASE+$007c	; [A|B] A/D Converter Result Register 6

ADR7H	=	REGBASE+$007e	; [A|B] A/D Converter Result Register 7

TIOS	=	REGBASE+$0080	; [A|B] Timer Input Capture/Output Compare Select
CFORC	=	REGBASE+$0081	; [A|B] Timer Compare Force Register
OC7M	=	REGBASE+$0082	; [A|B] Output Compare 7 Mask Register
OC7D	=	REGBASE+$0083	; [A|B] Output Compare 7 Data Register
TCNT	=	REGBASE+$0084	; [A|B] Timer Count Register (Word)
TSCR	=	REGBASE+$0086	; [A|B] Timer System Control Register
TQCR	=	REGBASE+$0087	; [A|B] Reserved
TCTL1	=	REGBASE+$0088	; [A|B] Timer Control Register 1
TCTL2	=	REGBASE+$0089	; [A|B] Timer Control Register 2
TCTL3	=	REGBASE+$008a	; [A|B] Timer Control Register 3
TCTL4	=	REGBASE+$008b	; [A|B] Timer Control Register 4
TMSK1	=	REGBASE+$008c	; [A|B] Timer Interrupt Mask 1
TMSK2	=	REGBASE+$008d	; [A|B] Timer Interrupt Mask 2
TFLG1	=	REGBASE+$008e	; [A|B] Timer Interrupt Flag 1
TFLG2	=	REGBASE+$008f	; [A|B] Timer Interrupt Flag 2
TC0		=	REGBASE+$0090	; [A|B] Timer Input Capture/Output Compare Register 0 (Word)
TC1		=	REGBASE+$0092	; [A|B] Timer Input Capture/Output Compare Register 1 (Word)
TC2		=	REGBASE+$0094	; [A|B] Timer Input Capture/Output Compare Register 2 (Word)
TC3		=	REGBASE+$0096	; [A|B] Timer Input Capture/Output Compare Register 3 (Word)
TC4		=	REGBASE+$0098	; [A|B] Timer Input Capture/Output Compare Register 4 (Word)
TC5		=	REGBASE+$009a	; [A|B] Timer Input Capture/Output Compare Register 5 (Word)
TC6		=	REGBASE+$009c	; [A|B] Timer Input Capture/Output Compare Register 6 (Word)
TC7		=	REGBASE+$009e	; [A|B] Timer Input Capture/Output Compare Register 7 (Word)
PACTL	=	REGBASE+$00a0	; [A|B] Pulse Accumulator Control Register
PAFLG	=	REGBASE+$00a1	; [A|B] Pulse Accumulator Flag Register
PACNT	=	REGBASE+$00a2	; [A|B] 16-bit Pulse Accumulator Count Register (Word)

TIMTST	=	REGBASE+$00ad	; [A|B] Timer Test Register
PORTT	=	REGBASE+$00ae	; [A|B] Port T Register
DDRT	=	REGBASE+$00af	; [A|B] Port T Data Direction Register

SC0BDH	=	REGBASE+$00c0	; [A|B] SCI 0 Baud Rate Control Register High
SC0BDL	=	REGBASE+$00c1	; [A|B] SCI 0 Baud Rate Control Register Low
SC0CR1	=	REGBASE+$00c2	; [A|B] SCI 0 Control Register 1
SC0CR2	=	REGBASE+$00c3	; [A|B] SCI 0 Control Register 2
SC0SR1	=	REGBASE+$00c4	; [A|B] SCI 0 Status Register 1
SC0SR2	=	REGBASE+$00c5	; [A|B] SCI 0 Status Register 2
SC0DRH	=	REGBASE+$00c6	; [A|B] SCI 0 Data Register High
SC0DRL	=	REGBASE+$00c7	; [A|B] SCI 0 Data Register Low
SC1BDH	=	REGBASE+$00c8	; [A|-] SCI 1 Baud Rate Control Register High
SC1BDL	=	REGBASE+$00c9	; [A|-] SCI 1 Baud Rate Control Register Low
SC1CR1	=	REGBASE+$00ca	; [A|-] SCI 1 Control Register 1
SC1CR2	=	REGBASE+$00cb	; [A|-] SCI 1 Control Register 2
SC1SR1	=	REGBASE+$00cc	; [A|-] SCI 1 Status Register 1
SC1SR2	=	REGBASE+$00cd	; [A|-] SCI 1 Status Register 2
SC1DRH	=	REGBASE+$00ce	; [A|-] SCI 1 Data Register High
SC1DRL	=	REGBASE+$00cf	; [A|-] SCI 1 Data Register Low
SP0CR1	=	REGBASE+$00d0	; [A|B] SPI Control Register 1
SP0CR2	=	REGBASE+$00d1	; [A|B] SPI Control Register 2
SP0BR	=	REGBASE+$00d2	; [A|B] SPI Baud Rate Register
SP0SR	=	REGBASE+$00d3	; [A|B] SPI Status Register

SP0DR	=	REGBASE+$00d5	; [A|B] SPI Data Register
PORTS	=	REGBASE+$00d6	; [A|B] Port S Register
DDRS	=	REGBASE+$00d7	; [A|B] Port S Data Direction Register

PURDS	=	REGBASE+$00db	; [-|B] Pullup and Reduced Drive for Port S

EEMCR	=	REGBASE+$00f0	; [A|B] EEPROM Module Configuration
EEPROT	=	REGBASE+$00f1	; [A|B] EEPROM Block Protect
EETST	=	REGBASE+$00f2	; [A|B] EEPROM Test
EEPROG	=	REGBASE+$00f3	; [A|B] EEPROM Control
FEELCK	=	REGBASE+$00f4	; [-|B] Flash EEPROM Lock Control Register
FEEMCR	=	REGBASE+$00f5	; [-|B] Flash EEPROM Module Configuration Register
FEETST	=	REGBASE+$00f6	; [-|B] Flash EEPROM Module Test Register
FEECTL	=	REGBASE+$00f7	; [-|B] Flash EEPROM Control Register
BCR1	=	REGBASE+$00f8	; [-|B] BDLC Control Register 1
BSVR	=	REGBASE+$00f9	; [-|B] BDLC State Vector Register
BCR2	=	REGBASE+$00fa	; [-|B] BDLC Control Register 2
BDR		=	REGBASE+$00fb	; [-|B] BDLC Data Register
BARD	=	REGBASE+$00fc	; [-|B] BDLC Analog Roundtrip Delay Register
DLCSCR	=	REGBASE+$00fd	; [-|B] Port DLC Control Register
PORTDLC	=	REGBASE+$00fe	; [-|B] Port DLC Data Register
DDRDLC	=	REGBASE+$00ff	; [-|B] Port DLC Data Direction Register

;== fine ======================================================================
