; =============================================================================
; Name: CRT12CO.S
; Func: ICC12 Startup Module
;       HC12compact Single Board Computer in Expanded Wide Mode
; Copr: Imagecraft Inc., additions by MCT/Oliver Thamm
; Vers: 1.1
; =============================================================================
;
; Do not define any .area above this line. .text must be the first
; line in this file.  You may put .area(s) at the end of the file.
;

	.include "hc12.i"

; You need to define two symbols on the link command line
;	init_sp		: initial stack pointer
;	heap_size 	: size of heap
; If you have target specific setup that you need to perform at the
; beginning, define it in a routine called __Setup (single _ if 
; written in C) and link it with your program.
; The entry point of your program is _start, which is defined here.
;
	.area text
__start::				; entry point
	;
	; Critical MCU settings first
	; REM: MCU starts in NormExpMode
	;
	clr  COPCTL			; Disable Watchdog
	movb #$0c,PEAR		; LSTRE+RDWE, ECLK
	movb #$3F,CSCTL0	; Enable CSP0+CSD+CS3+CS2+CS1+CS0
	movb #$10,CSCTL1	; CSD covers $0000-$7fff
	movb #$30,CSSTR0	; CSP0+CSD not stretched (CSP1:3x)
	movb #$FF,CSSTR1	; CS0..3 stretched (3x)
	movb #$fe,PPAGE		; Program Page $FE
	movb #$c0,WINDEF	; DWEN+PWEN
	movb #$0f,MXAR		; A16E...A19E
	movb #$80,DDRE		; PE7=Out (LED driver)
	movb #$00,PORTE		; LED on
	;
	; Optional (if you want to protect the EEPROM array):
	;
	movb #$ff,EEPROT	; Protect EEPROM
	movb #$fe,EEMCR		; Lock protection
	;
	lds	#init_sp		; now we have access to the ext. RAM too...
	;
	jsr	__HC12Setup		; define your own setup rtn if you want to do
						; initialization stuff before main()
; clear BSS
	clra
	ldx	#__bss_start
init_loop:
	cpx	#__bss_end
	beq	init_done
	staa	0,x
	inx
	bra	init_loop

init_done:
; copy initialized idata to data
	ldx	#__idata_start
	ldy	#__data_start
copy_loop:
	cpx	#__idata_end
	beq copy_done
	movb 1,x+,1,y+
	bra copy_loop
copy_done:

; to save additional space, comment out this block of code if you are not
; using heap so that NewHeap will not be dragged in. Otherwise, even if
; you set heap_size to zer0, code for NewHeap still gets pulled in.
;
; set up heap space
	ldd	#heap_size
	beq	heap_done
	addd #__bss_end
	pshb
	psha
	ldd	#__bss_end
	jsr	__NewHeap
	pulx
heap_done:
; call user main routine
	jsr _main
_exit::
	bra	_exit

    ; __idata_start MUST follow text area for it to be in ROM
	.area idata
__idata_start::

	.area data
__data_start::

	.area bss
__bss_start::
