;==============================================================================
; File: RTC12C.S
; Func: HC12compact Driver Routines for RTC4553
; Copr: (C)1998 by MCT, Oliver Thamm
; Vers: 1.2
;==============================================================================

	.include "hc12.i"

; SPICOD0 = PH4 = 0 > selects
; SPICOD1 = PH5 = 0 > the RTC
; /WRRTC  = PH6

	.area text

;------------------------------------------------------------------------------
; void initRTC(void);
;
_initRTC::	bset PORTH,$40		; /WRRTC (PH6) = H
			bset DDRH,$40		; PH6 Output
			rts


;------------------------------------------------------------------------------
; int getRTC(unsigned aregno);
;
; Args: B[3..0] = register number
; Retn: B[3..0] = register number
;       B[7..4] = data
;       A = 0
;
_getRTC::	movb #$5d,SP0CR1	; SPE+MSTR+CPOL+CPHA+LSBF
			bset PORTH,$40		; /WRRTC = H
			bclr PORTH,$30		; SPICOD0/1 = L (enable SPICS0)
			jsr  _xferSPI		; send Register Address
			jsr  _xferSPI		; receive Data from RTC
			bset PORTH,$30		; SPICOD0/1 = H (disable SPI slaves)
			clra
			rts


;------------------------------------------------------------------------------
; unsigned peekRTC(unsigned addr);
;
_peekRTC::	andb #$0f
			pshd				; save addr at 1,sp
			ldab #$2f			; select bank 2 (mode 1)
			jsr  _putRTC
			ldab 1,sp			; pushed addr
			jsr  _getRTC		; get high nibble
			andb #$f0
			stab 0,sp			; save high nibble
			ldab #$3f			; select bank 3 (mode 2)
			jsr  _putRTC
			ldab 1,sp			; pushed addr
			jsr  _getRTC		; get low nibble
			lsrb
			lsrb
			lsrb
			lsrb
			addb 0,sp			; low nibble + high nibble
			clr  0,sp			; prepare retval: A = 0
			stab 1,sp			; B = value
			ldab #$0f			; select bank 0 (default mode 0)
			jsr  _putRTC
			puld				; return A:B
			rts


;------------------------------------------------------------------------------
; void putRTC(unsigned abyte);
;
; Args: B[3..0] = register number
;       B[7..4] = data
;
_putRTC::	pshd
			movb #$5d,SP0CR1	; SPE+MSTR+CPOL+CPHA+LSBF
			bclr PORTH,$40		; /WRRTC = L
			bclr PORTH,$30		; SPICOD0/1 = L (enable SPICS0)
			jsr  _xferSPI		; send Register Address + Data
			bset PORTH,$30		; SPICOD0/1 = H (disable SPI slaves)
			puld
			rts


;------------------------------------------------------------------------------
; void pokeRTC(unsigned aregno, unsigned newval);

_pokeRTC::	cpd  #15			; aregno < 15!
			bhs  __pokrtcx
			pshd				; aregno -> 1,sp; newval -> 5,sp
			ldab #$2f			; select bank 2 (mode 1)
			jsr  _putRTC
			ldab 5,sp			; newval
			andb #$f0
			addb 1,sp			; register number
			jsr  _putRTC		; write high nibble
			ldab #$3f			; select bank 3 (mode 2)
			jsr  _putRTC
			ldab 5,sp			; newval
			lslb
			lslb
			lslb
			lslb
			addb 1,sp			; register number
			jsr  _putRTC		; write low nibble
			ldab #$0f			; select bank 0 (default mode 0)
			jsr  _putRTC
			puld
__pokrtcx:	rts


;------------------------------------------------------------------------------
; void getTimeDate(struct timedate *abuffer);
;
; Func: Get time and date from RTC
; Args: D = Buffer[6]
; Retn:	[S,M,H,D,M,Y] in Buffer (BCD coded)
; Rem.: This functions takes less than 1ms
;       (plus 3.9ms in the worst case for a BUSY wait)
;       AM/PM and DayOfWeek are ignored
;
_getTimeDate::
			pshx
			tfr d,x
			jsr  __waitRTCBusy
			clrb				; Register Counter = 0
__gtim1:	jsr  __getTimVal
			inx
			incb
			incb
			cmpb #6				; skip register 6 (W)
			bne  __gtim2
			incb
__gtim2:	cmpb #13			; stop before reg 13
			bne  __gtim1
			bclr -4,x,$80		; mask out AM/PM bit
			pulx
			rts


;------------------------------------------------------------------------------
; void setTimeDate(struct timedate *abuffer);
;
; Func: Set time and date of RTC
; Args: D = Buffer[6] with [S,M,H,D,M,Y] (BCD coded)
; Rem.: AM/PM and DayOfWeek not used, 24hr format
;
_setTimeDate::
			pshx
			tfr d,x
			ldab #$8f			; CNT3 = %1000 (SYSR - SYStemReset) 
			jsr  _putRTC		; reset to SU 01.01.00 12:00:00 AM
			ldab #$1d			; CNT1 = %0001 (24HR MODE)
			jsr  _putRTC
			jsr  __waitRTCBusy	; can we start setting time+date?
			;
			ldaa 5,x			; Year
			ldab #$0b			; year register
			bsr  __setTimVal
			ldaa 4,x			; Month
			bsr  __decBCD			; default after SYSR is 1!
			ldab #$09			; month register
			bsr  __setTimVal
			ldaa 3,x			; Day
			bsr  __decBCD			; default after SYSR is 1!
			ldab #$07			; day register
			bsr  __setTimVal
			ldaa 2,x			; Hour
			ldab #$04			; hour register
			bsr  __setTimHour
			ldaa 1,x			; Minute
			ldab #$02			; minute register
			bsr  __setTimVal
			pulx
			rts


; Func: Decrement BCD value
; Args: A = BCD[2]
; Retn: A
;
__decBCD	adda #$99
		daa
		rts


;==============================================================================
; Func: wait until BUSY condition is gone
; Args: -
;
__waitRTCBusy:
			pshd
__wrtcb1:	ldab #$0e			; get CNT2 register
			jsr  _getRTC
			tstb				; check if BUSY set
			bmi  __wrtcb1		; wait!
			puld
			rts					; min. 3.8ms until next BUSY


;------------------------------------------------------------------------------
; Func: Set both digits of a RTC value
; Args: A=Value(BCD)
;       B=Register
; Dest: A,B!
;
__setTimVal:
			psha
			anda #$0f
			bsr  __setTimDig		; 1-digit
			pula
			lsra
			lsra
			lsra
			lsra
			incb					; next reg addr
			bsr  __setTimDig		; 10-digit
			rts


;------------------------------------------------------------------------------
; Func: Set a RTC value by incrementing only the 1s digit
; Args: A=Value
;       B=Register
;
__setTimHour:
			bsr  __convBCD1			; Hour: Increment 1s only
			bra  __setTimDig		; (so we have to convert BCD to Dec)

;------------------------------------------------------------------------------
; Func: Set one digit of a RTC value
; Args: A=Digit-Value
;       B=Register
;
__stimincr:	jsr  _putRTC
__setTimDig:
			deca
			bpl  __stimincr
			rts


;------------------------------------------------------------------------------
; Func: Convert 2 digits BCD to Decimal
; Args: A = BCD[2]
; Retn: A = Dec
;
__convBCD1:	pshb
			pshy
			ldy  #8					; 8 Bit result
__cnvbd0:	lsra					; A/2
			rorb					; Remainder -> B
			bita #$08				; Adjust BCD?
			beq  __cnvbd1
			suba #$03
__cnvbd1:	dey
			bne  __cnvbd0
			tba
			puly
			pulb
			rts


;------------------------------------------------------------------------------
; Func: Get value (1-digit + 10-digit) from RTC
; Args: B = register
;       X = timedate buffer
; Retn: -
; Dest: -
;
__getTimVal:
			pshd
			pshb
			jsr  _getRTC
			lsrb
			lsrb
			lsrb
			lsrb
			stab 0,x
			pulb
			incb
			jsr  _getRTC
			andb #$f0
			addb 0,x
			stab 0,x
			puld
			rts


;==============================================================================

