//=============================================================================
// File: SONGDEMO.C
// Func: HC12compact plays a little song
// Copr: (C)1998 by MCT, Oliver Thamm (the code, not the song...)
// Rem.: Link with SND12C.O and load/start with TwinPEEKs!!
//=============================================================================

#include <stdio.h>
#include "hc12co.h"

//-- Note Definitions (fit in a single byte) ----------------------------------

// note codes (Bit0..3)
#define _C	    0x01
#define _CIS    0x02
#define _D	    0x03
#define _DIS    0x04
#define _E	    0x05
#define _F	    0x06
#define _FIS    0x07
#define _G	    0x08
#define _GIS    0x09
#define _A	    0x0a
#define _AIS    0x0b
#define _H	    0x0c
// pause
#define _PP		0x00

// octave codes (Bit4)
#define _HIGH	0x00
#define _DEEP	0x10

// duration codes (Bit5,6)
#define _1_8    0x20
#define _1_4	0x00
#define _3_8	0x60
#define _1_2	0x40

// end of song code (Bit7)
#define _STOP	0x80


// frequency definitions
const unsigned ftable[] = {
	0,		// pause
	523,	// c
	554,	// cis
	587,	// d
	622,	// dis
	659,	// e
	698,	// f
	740,	// fis
	784,	// g
	830,	// gis
	880,	// a
	932,	// ais
	987 	// h
	};

//-- The Song -----------------------------------------------------------------

#include "song1.h"

//-----------------------------------------------------------------------------

void delay(unsigned duration) {

	do {
		int i;
		for(i=0; i<5000; i++) ;		// adjust this to change the beat
		} while(--duration);
	}

//-----------------------------------------------------------------------------

void playNote(unsigned char note) {

		unsigned freq, dura;

		if(note & 0x80) return;

		// get frequency
		freq  = ftable[note & 0x0f];

		// low octave -> frequency/2
		if((note & 0x10) == _DEEP) freq = freq >> 1;

		switch(note & 0x60) {
			case _1_8:	dura = 25;
						break;
			case _1_4:	dura = 50;
						break;
			case _3_8:	dura = 75;
						break;
			case _1_2:	dura = 100;
						break;
			}
		sound(freq);
		delay(dura-5);
		nosound();
		delay(5);
		}

//-----------------------------------------------------------------------------

void main(void) {

	int k;

	// install OC2 pseudo vector in RAM
	// (if running with TwinPEEKs monitor)
    *((unsigned char *)0x0be2) = 0x06;	// JMP opcode
    *((void (**)(void))0x0be3) = isrOC2;

	initSND();
	INTR_ON();	// allow interrupts

	k = 0;
	while(Song[k] != _STOP) {
		playNote(Song[k++]);
		}
	}

//=============================================================================
